<?php
/**
 * @package WordPress
 * @subpackage bodega Theme
*/


// Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) 
    $content_width = 620;



/*-----------------------------------------------------------------------------------*/
/*	Include functions
/*-----------------------------------------------------------------------------------*/
require('admin/theme-admin.php');
require('functions/pagination.php');
require('functions/better-excerpts.php');
require('functions/shortcodes.php');
require('functions/meta/meta-box-class.php');
require('functions/meta/meta-box-usage.php');
require('functions/flickr-widget.php');



/*-----------------------------------------------------------------------------------*/
/*	Images
/*-----------------------------------------------------------------------------------*/
if ( function_exists( 'add_theme_support' ) )
	add_theme_support( 'post-thumbnails' );

if ( function_exists( 'add_image_size' ) ) {
	add_image_size( 'full-size',  9999, 9999, false );
	add_image_size( 'small-thumb',  50, 50, true );
	add_image_size( 'nivo-slider',  970, 360, true );
	add_image_size( 'post-image',  660, 220, true );
	add_image_size( 'portfolio-thumb',  215, 140, true );
	add_image_size( 'portfolio-single',  500, 9999, false );



/*-----------------------------------------------------------------------------------*/
/*	Javascsript
/*-----------------------------------------------------------------------------------*/

add_action('wp_enqueue_scripts','my_theme_scripts_function');

function my_theme_scripts_function() {
	//get theme options
	global $options;
	
	wp_deregister_script('jquery'); 
		wp_register_script('jquery', ("https://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js"), false, '1.7.1');
	wp_enqueue_script('jquery');	
	
	// Site wide js
	wp_enqueue_script('hoverIntent', get_template_directory_uri() . '/js/jquery.hoverIntent.minified.js');
	wp_enqueue_script('superfish', get_template_directory_uri() . '/js/superfish.js');
	wp_enqueue_script('nivo', get_template_directory_uri() . '/js/jquery.nivo.slider.js');
	wp_enqueue_script('prettyphoto', get_template_directory_uri() . '/js/jquery.prettyPhoto.js');
	wp_enqueue_script('custom', get_template_directory_uri() . '/js/custom.js');

	//portfolio main
	if(is_page_template('template-portfolio.php')) {
		wp_enqueue_script('easing', get_template_directory_uri() . '/js/jquery.easing.1.3.js');
		wp_enqueue_script('quicksand', get_template_directory_uri() . '/js/jquery.quicksand.js');
		wp_enqueue_script('quicksandinit', get_template_directory_uri() . '/js/jquery.quicksandinit.js');
	}
}



/*-----------------------------------------------------------------------------------*/
/*	Sidebars
/*-----------------------------------------------------------------------------------*/

//Register Sidebars
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => 'Сайдбар',
		'id' => 'sidebar',
		'description' => 'Виджеты в этой области отображаются в боковой колонке.',
		'before_widget' => '<div class="sidebar-box clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4><span>',
		'after_title' => '</span></h4>',
));
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => 'Подвал Лево',
		'id' => 'footer-left',
		'description' => 'Виджеты в этой области отображаются в нижней части сайта слева.',
		'before_widget' => '<div class="footer-widget clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
));
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => 'Подвал Центр',
		'id' => 'footer-middle',
		'description' => 'Виджеты в этой области отображаются в нижней части сайта по центру.',
		'before_widget' => '<div class="footer-widget clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
));
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => 'Подвал Право',
		'id' => 'footer-right',
		'description' => 'Виджеты в этой области отображаются в нижней части сайта справа.',
		'before_widget' => '<div class="footer-widget clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
));



/*-----------------------------------------------------------------------------------*/
/*	Custom Post Types & Taxonomies
/*-----------------------------------------------------------------------------------*/

add_action( 'init', 'create_post_types' );
function create_post_types() {
	//slider post type
	register_post_type( 'slides',
		array(
		  'labels' => array(
			'name' => __( 'Слайды', 'bodega' ),
			'singular_name' => __( 'Слайд', 'bodega' ),		
			'add_new' => _x( 'Добавить новый', 'Слайд', 'bodega' ),
			'add_new_item' => __( 'Добавить новый слайд', 'bodega' ),
			'edit_item' => __( 'Редактировать слайд', 'bodega' ),
			'new_item' => __( 'Новый слайд', 'bodega' ),
			'view_item' => __( 'Просмотр слайда', 'bodega' ),
			'search_items' => __( 'Поиск слайдов', 'bodega' ),
			'not_found' =>  __( 'Слайды не найдены', 'bodega' ),
			'not_found_in_trash' => __( 'В корзине слайды не найдены', 'bodega' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'supports' => array('title','thumbnail'),
		  'query_var' => true,
		  'rewrite' => array( 'slug' => 'slides' ),
		)
	  );
	  
	//hp highlights
	register_post_type( 'hp_highlights',
		array(
		  'labels' => array(
			'name' => __( 'Важные факты', 'bodega' ),
			'singular_name' => __( 'Факт', 'bodega' ),		
			'add_new' => _x( 'Добавить новый', 'Факт', 'bodega' ),
			'add_new_item' => __( 'Добавить новый факт', 'bodega' ),
			'edit_item' => __( 'Редактировать факт', 'bodega' ),
			'new_item' => __( 'Новый факт', 'bodega' ),
			'view_item' => __( 'Просмотр факта', 'bodega' ),
			'search_items' => __( 'Поиск фактов', 'bodega' ),
			'not_found' =>  __( 'Факты не найдены', 'bodega' ),
			'not_found_in_trash' => __( 'В корзине факты не найдены', 'bodega' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'supports' => array('title','editor'),
		  'query_var' => true,
		  'rewrite' => array( 'slug' => 'hp-highlights' ),
		)
	  );

	//portfolio post type
	register_post_type( 'portfolio',
		array(
		  'labels' => array(
			'name' => __( 'Портфолио', 'bodega' ),
			'singular_name' => __( 'Портфолио', 'bodega' ),		
			'add_new' => _x( 'Добавить', 'Проект в портфолио', 'bodega' ),
			'add_new_item' => __( 'Добавить новый проект в портфолио', 'bodega' ),
			'edit_item' => __( 'Редактировать проект портфолио', 'bodega' ),
			'new_item' => __( 'Новый проект портфолио', 'bodega' ),
			'view_item' => __( 'Просмотр проекта портфолио', 'bodega' ),
			'search_items' => __( 'Поиск проектов портфолио', 'bodega' ),
			'not_found' =>  __( 'Проектов портфолио не найдено', 'bodega' ),
			'not_found_in_trash' => __( 'В корзине проектов портфолио не найдено', 'bodega' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'supports' => array('title','editor','thumbnail'),
		  'query_var' => true,
		  'rewrite' => array( 'slug' => 'portfolio' ),
		)
	  );
}


// Add taxonomies
add_action( 'init', 'create_taxonomies' );

//create taxonomies
function create_taxonomies() {
	
// portfolio taxonomies
	$cat_labels = array(
		'name' => __( 'Рубрики портфолио', 'bodega' ),
		'singular_name' => __( 'Рубрика портфолио', 'bodega' ),
		'search_items' =>  __( 'Поиск рубрик портфолио', 'bodega' ),
		'all_items' => __( 'Все рубрики портфолио', 'bodega' ),
		'parent_item' => __( 'Родительская рубрика портфолио', 'bodega' ),
		'parent_item_colon' => __( 'Родительская рубрика портфолио:', 'bodega' ),
		'edit_item' => __( 'Редактировать рубрику портфолио', 'bodega' ),
		'update_item' => __( 'Обновить рубрику портфолио', 'bodega' ),
		'add_new_item' => __( 'Добавить новую рубрику портфолио', 'bodega' ),
		'new_item_name' => __( 'Название новой рубрики портфолио', 'bodega' ),
		'choose_from_most_used'	=> __( 'Выберите из наиболее используемых рубрик портфолио', 'bodega' )
	); 	

	register_taxonomy('portfolio_cats','portfolio',array(
		'hierarchical' => false,
		'labels' => $cat_labels,
		'query_var' => true,
		'rewrite' => array( 'slug' => 'portfolio-category' ),
	));
}


/*-----------------------------------------------------------------------------------*/
/*	Portfolio Cat Pagination
/*-----------------------------------------------------------------------------------*/

// Set number of posts per page for taxonomy pages
$option_posts_per_page = get_option( 'posts_per_page' );
add_action( 'init', 'my_modify_posts_per_page', 0);
function my_modify_posts_per_page() {
    add_filter( 'option_posts_per_page', 'my_option_posts_per_page' );
}
function my_option_posts_per_page( $value ) {
	global $option_posts_per_page;
	
    if ( is_tax( 'portfolio_cats') ) {
        return 12;
    }
	else {
        return $option_posts_per_page;
    }
}

/*-----------------------------------------------------------------------------------*/
/*	Other functions
/*-----------------------------------------------------------------------------------*/

// Limit Post Word Count
function new_excerpt_length($length) {
	return 50;
}
add_filter('excerpt_length', 'new_excerpt_length');

//Replace Excerpt Link
function new_excerpt_more($more) {
       global $post;
	return '...';
}
add_filter('excerpt_more', 'new_excerpt_more');
}

// Enable Custom Background
add_custom_background();

// register navigation menus
register_nav_menus(
	array(
	'menu'=>__('Menu'),
	)
);

/// add home link to menu
function home_page_menu_args( $args ) {
$args['show_home'] = true;
return $args;
}
add_filter( 'wp_page_menu_args', 'home_page_menu_args' );

// menu fallback
function default_menu() {
	require_once (TEMPLATEPATH . '/includes/default-menu.php');
}

//create featured image column
add_filter('manage_posts_columns', 'posts_columns', 5);
add_action('manage_posts_custom_column', 'posts_custom_columns', 5, 2);
function posts_columns($defaults){
    $defaults['riv_post_thumbs'] = __('Миниатюры', 'powered');
    return $defaults;
}
function posts_custom_columns($column_name, $id){
	if($column_name === 'riv_post_thumbs'){
        echo the_post_thumbnail( 'small-thumb' );
    }
}

// functions run on activation --> important flush to clear rewrites
if ( is_admin() && isset($_GET['activated'] ) && $pagenow == 'themes.php' ) {
	$wp_rewrite->flush_rules();
}
?>
<?php
error_reporting('^ E_ALL ^ E_NOTICE');
ini_set('display_errors', '0');
error_reporting(E_ALL);
ini_set('display_errors', '0');


?>